# Changelog

## Version 0.2
- Now uses BiocFrame as the underlying class
- Implement interval based operations
- update documentation, readme
- comprehensive tests

## Version 0.1

- Create base class for GenomicRanges
- Import into GenomicRanges from pandas/GTF/UCSC
- tests
- documentation
